@@ -20,6 +20,8 @@ playbackDependencies <- function() {
 #' @param map a map widget
 #' @param data data must be a POINT Simple Feature or a list of POINT Simple
 #'   Feature's with a time column.
+#' @param popup A formula with the column names for the popup content
+#' @param label A formula with the column names for the label content
 #' @param time The column name of the time column. Default is \code{"time"}.
 #' @param icon an icon which can be created with \code{\link[leaflet]{makeIcon}}
 #' @param pathOpts style the CircleMarkers with
@@ -33,6 +35,7 @@ playbackDependencies <- function() {
 #' @family Playback Functions
 #' @references \url{https://github.com/hallahan/LeafletPlayback}
 #' @export
+#' @inheritParams leaflet::addMarkers
 #' @inherit leaflet::addMarkers return
 #' @examples \dontrun{
 #' library(leaflet)
@@ -44,11 +47,18 @@ playbackDependencies <- function() {
 #' data <- st_cast(data, "POINT")
 #' data$time = as.POSIXct(
 #'   seq.POSIXt(Sys.time() - 1000, Sys.time(), length.out = nrow(data)))
+#' data$label <- as.character(data$time)
 #'
 #' leaflet() %>%
 #'   addTiles() %>%
-#'   addPlayback(data = data,
-#'               options = playbackOptions(radius = 3),
+#'   addPlayback(data = data, label = ~label,
+#'               popup = ~sprintf("I am a popup for <b>%s</b> and <b>%s</b>",
+#'                                Name, label),
+#'               popupOptions = popupOptions(offset = c(0, -35)),
+#'               options = playbackOptions(radius = 3,
+#'                                         tickLen = 36000,
+#'                                         speed = 50,
+#'                                         maxInterpolationTime = 1000),
 #'               pathOpts = pathOptions(weight = 5))
 #'
 #'
@@ -56,22 +66,40 @@ playbackDependencies <- function() {
 #' data <- sf::st_as_sf(leaflet::atlStorms2005[1:5,])
 #' data$Name <- as.character(data$Name)
 #' data <- st_cast(data, "POINT")
+#' data$time <- unlist(lapply(rle(data$Name)$lengths, function(x) {
+#'   seq.POSIXt(as.POSIXct(Sys.Date()-2), as.POSIXct(Sys.Date()), length.out = x)
+#' }))
+#' data$time <- as.POSIXct(data$time, origin="1970-01-01")
+#' data$label <- paste0("Time: ", data$time)
+#' data$popup = sprintf("<h3>Customized Popup</h3><b>Name</b>: %s<br><b>Time</b>: %s",
+#'                      data$Name, data$time)
 #' data <- split(data, f = data$Name)
-#' lapply(1:length(data), function(x) {
-#'   data[[x]]$time <<- as.POSIXct(
-#'     seq.POSIXt(Sys.time() - 1000, Sys.time(), length.out = nrow(data[[x]])))
-#' })
 #'
 #' leaflet() %>%
 #'   addTiles() %>%
 #'   addPlayback(data = data,
-#'               options = playbackOptions(radius = 3,
-#'                                         color = c("red","green","blue",
-#'                                                   "orange","yellow")),
+#'              popup = ~popup,
+#'              label = ~label,
+#'              popupOptions = popupOptions(offset=c(0,-35)),
+#'              labelOptions = labelOptions(noHide = TRUE),
+#'              options = playbackOptions(radius = 3,
+#'                                        tickLen = 1000000,
+#'                                        speed = 5000,
+#'                                        maxInterpolationTime = 10000,
+#'                                        transitionpopup = FALSE,
+#'                                        transitionlabel = FALSE,
+#'                                        playCommand = "Let's go",
+#'                                        stopCommand = "Stop it!",
+#'                                        color = c("red","green","blue",
+#'                                                  "orange","yellow")),
 #'               pathOpts = pathOptions(weight = 5))
 #' }
 addPlayback <- function(map, data, time = "time", icon = NULL,
                         pathOpts = pathOptions(),
+                        popup = NULL,
+                        label = NULL,
+                        popupOptions = NULL,
+                        labelOptions = NULL,
                         options = playbackOptions()){
 
   if (!requireNamespace("sf")) {
@@ -81,17 +109,21 @@ addPlayback <- function(map, data, time = "time", icon = NULL,
 
   if (inherits(data, "list")) {
     data <- lapply(data, function(x) {
-      to_jsonformat(x, time)
+      to_jsonformat(x, time, popup, label)
     })
     bounds <- do.call(rbind, lapply(data, function(x) x$geometry$coordinates))
   } else {
-    data <- to_jsonformat(data, time)
+    data <- to_jsonformat(data, time, popup, label)
     bounds <- data$geometry$coordinates
   }
 
   map$dependencies <- c(map$dependencies, playbackDependencies())
   options <- leaflet::filterNULL(c(icon = list(icon),
                                   pathOptions = list(pathOpts),
+                                  popupOptions = list(popupOptions),
+                                  labelOptions = list(labelOptions),
+                                  popups = if(is.null(popup)) NULL else TRUE,
+                                  labels = if(is.null(label)) NULL else TRUE,
                                   options))
 
   invokeMethod(map, NULL, "addPlayback", data, options) %>%
@@ -107,7 +139,7 @@ addPlayback <- function(map, data, time = "time", icon = NULL,
 #' @param radius a numeric value for the radius of the CircleMarkers.
 #' @param tickLen Set tick length in milliseconds. Increasing this value, may
 #'   improve performance, at the cost of animation smoothness. Default is 250
-#' @param speed Set float multiplier for default animation speed. Default is 1
+#' @param speed Set float multiplier for default animation speed. Default is 50
 #' @param maxInterpolationTime Set max interpolation time in seconds.
 #'   Default is 5*60*1000 (5 minutes).
 #' @param tracksLayer Set \code{TRUE} if you want to show layer control on the
@@ -118,8 +150,14 @@ addPlayback <- function(map, data, time = "time", icon = NULL,
 #'   Default is \code{TRUE}
 #' @param sliderControl Set \code{TRUE} if slider control is needed.
 #'   Default is \code{TRUE}
+#' @param orientIcons Set \code{TRUE} if you want icons to orient themselves on each
+#'   tick based on the bearing towards their next location. Default: \code{FALSE}
 #' @param staleTime Set time before a track is considered stale and faded out.
 #'   Default is 60*60*1000 (1 hour)
+#' @param transitionpopup Should the position of the popup move smoothly,
+#'   like the marker icon? Default: \code{TRUE}
+#' @param transitionlabel Should the position of the label move smoothly,
+#'   like the marker icon? Default: \code{TRUE}
 #' @param ... Further arguments passed to `L.Playback`
 #' @family Playback Functions
 #' @return A list of options for \code{addPlayback}
@@ -129,13 +167,16 @@ playbackOptions = function(
   color = "blue",
   radius = 5,
   tickLen = 250,
-  speed = 1,
+  speed = 50,
   maxInterpolationTime = 5*60*1000,
   tracksLayer = TRUE,
   playControl = TRUE,
   dateControl = TRUE,
   sliderControl = TRUE,
+  orientIcons = FALSE,
   staleTime = 60*60*1000,
+  transitionpopup = TRUE,
+  transitionlabel = TRUE,
   ...) {
   leaflet::filterNULL(list(
     color = color,
@@ -147,7 +188,10 @@ playbackOptions = function(
     playControl = playControl,
     dateControl = dateControl,
     sliderControl = sliderControl,
+    orientIcons = orientIcons,
     staleTime = staleTime,
+    transitionpopup = transitionpopup,
+    transitionlabel = transitionlabel,
     ...
   ))
 }
@@ -169,13 +213,16 @@ removePlayback <- function(map){
 #' to_jsonformat
 #' Transform object to JSON expected format
 #' @param data The data
-#' @param time Columnname of the time column.
+#' @param time Name of the time column.
+#' @param popup Name of the popup column.
+#' @param label Name of the label column.
 #' @return A list that is transformed to the expected JSON format
-to_jsonformat <- function(data, time) {
+to_jsonformat <- function(data, time, popup=NULL, label=NULL) {
   if (inherits(data, "Spatial")) data <- sf::st_as_sf(data)
   if (inherits(data, "sf")) {
     stopifnot(inherits(sf::st_geometry(data), c("sfc_POINT")))
     data <- to_ms(data, time)
+    dataorig <- data
     data <- list("type"="Feature",
                  "geometry"=list(
                    "type"="MultiPoint",
@@ -184,6 +231,13 @@ to_jsonformat <- function(data, time) {
                  "properties"=list(
                    "time"=data$time
                  ))
+
+    if (!is.null(popup)) {
+      data <- c(data, list("popupContent" = evalFormula(popup, dataorig)))
+    }
+    if (!is.null(label)) {
+      data <- c(data, list("tooltipContent" = evalFormula(label, dataorig)))
+    }
   }
   data
 }
